function noop() { }
function assign(tar, src) {
    // @ts-ignore
    for (const k in src)
        tar[k] = src[k];
    return tar;
}
function run(fn) {
    return fn();
}
function blank_object() {
    return Object.create(null);
}
function run_all(fns) {
    fns.forEach(run);
}
function is_function(thing) {
    return typeof thing === 'function';
}
function safe_not_equal(a, b) {
    return a != a ? b == b : a !== b || ((a && typeof a === 'object') || typeof a === 'function');
}
function is_empty(obj) {
    return Object.keys(obj).length === 0;
}
function create_slot(definition, ctx, $$scope, fn) {
    if (definition) {
        const slot_ctx = get_slot_context(definition, ctx, $$scope, fn);
        return definition[0](slot_ctx);
    }
}
function get_slot_context(definition, ctx, $$scope, fn) {
    return definition[1] && fn
        ? assign($$scope.ctx.slice(), definition[1](fn(ctx)))
        : $$scope.ctx;
}
function get_slot_changes(definition, $$scope, dirty, fn) {
    if (definition[2] && fn) {
        const lets = definition[2](fn(dirty));
        if ($$scope.dirty === undefined) {
            return lets;
        }
        if (typeof lets === 'object') {
            const merged = [];
            const len = Math.max($$scope.dirty.length, lets.length);
            for (let i = 0; i < len; i += 1) {
                merged[i] = $$scope.dirty[i] | lets[i];
            }
            return merged;
        }
        return $$scope.dirty | lets;
    }
    return $$scope.dirty;
}
function update_slot(slot, slot_definition, ctx, $$scope, dirty, get_slot_changes_fn, get_slot_context_fn) {
    const slot_changes = get_slot_changes(slot_definition, $$scope, dirty, get_slot_changes_fn);
    if (slot_changes) {
        const slot_context = get_slot_context(slot_definition, ctx, $$scope, get_slot_context_fn);
        slot.p(slot_context, slot_changes);
    }
}
function null_to_empty(value) {
    return value == null ? '' : value;
}

function append(target, node) {
    target.appendChild(node);
}
function insert(target, node, anchor) {
    target.insertBefore(node, anchor || null);
}
function detach(node) {
    node.parentNode.removeChild(node);
}
function element(name) {
    return document.createElement(name);
}
function text(data) {
    return document.createTextNode(data);
}
function space() {
    return text(' ');
}
function attr(node, attribute, value) {
    if (value == null)
        node.removeAttribute(attribute);
    else if (node.getAttribute(attribute) !== value)
        node.setAttribute(attribute, value);
}
function children(element) {
    return Array.from(element.childNodes);
}
function set_style(node, key, value, important) {
    node.style.setProperty(key, value, important ? 'important' : '');
}

let current_component;
function set_current_component(component) {
    current_component = component;
}

const dirty_components = [];
const binding_callbacks = [];
const render_callbacks = [];
const flush_callbacks = [];
const resolved_promise = Promise.resolve();
let update_scheduled = false;
function schedule_update() {
    if (!update_scheduled) {
        update_scheduled = true;
        resolved_promise.then(flush);
    }
}
function add_render_callback(fn) {
    render_callbacks.push(fn);
}
let flushing = false;
const seen_callbacks = new Set();
function flush() {
    if (flushing)
        return;
    flushing = true;
    do {
        // first, call beforeUpdate functions
        // and update components
        for (let i = 0; i < dirty_components.length; i += 1) {
            const component = dirty_components[i];
            set_current_component(component);
            update(component.$$);
        }
        set_current_component(null);
        dirty_components.length = 0;
        while (binding_callbacks.length)
            binding_callbacks.pop()();
        // then, once components are updated, call
        // afterUpdate functions. This may cause
        // subsequent updates...
        for (let i = 0; i < render_callbacks.length; i += 1) {
            const callback = render_callbacks[i];
            if (!seen_callbacks.has(callback)) {
                // ...so guard against infinite loops
                seen_callbacks.add(callback);
                callback();
            }
        }
        render_callbacks.length = 0;
    } while (dirty_components.length);
    while (flush_callbacks.length) {
        flush_callbacks.pop()();
    }
    update_scheduled = false;
    flushing = false;
    seen_callbacks.clear();
}
function update($$) {
    if ($$.fragment !== null) {
        $$.update();
        run_all($$.before_update);
        const dirty = $$.dirty;
        $$.dirty = [-1];
        $$.fragment && $$.fragment.p($$.ctx, dirty);
        $$.after_update.forEach(add_render_callback);
    }
}
const outroing = new Set();
let outros;
function group_outros() {
    outros = {
        r: 0,
        c: [],
        p: outros // parent group
    };
}
function check_outros() {
    if (!outros.r) {
        run_all(outros.c);
    }
    outros = outros.p;
}
function transition_in(block, local) {
    if (block && block.i) {
        outroing.delete(block);
        block.i(local);
    }
}
function transition_out(block, local, detach, callback) {
    if (block && block.o) {
        if (outroing.has(block))
            return;
        outroing.add(block);
        outros.c.push(() => {
            outroing.delete(block);
            if (callback) {
                if (detach)
                    block.d(1);
                callback();
            }
        });
        block.o(local);
    }
}
function mount_component(component, target, anchor) {
    const { fragment, on_mount, on_destroy, after_update } = component.$$;
    fragment && fragment.m(target, anchor);
    // onMount happens before the initial afterUpdate
    add_render_callback(() => {
        const new_on_destroy = on_mount.map(run).filter(is_function);
        if (on_destroy) {
            on_destroy.push(...new_on_destroy);
        }
        else {
            // Edge case - component was destroyed immediately,
            // most likely as a result of a binding initialising
            run_all(new_on_destroy);
        }
        component.$$.on_mount = [];
    });
    after_update.forEach(add_render_callback);
}
function destroy_component(component, detaching) {
    const $$ = component.$$;
    if ($$.fragment !== null) {
        run_all($$.on_destroy);
        $$.fragment && $$.fragment.d(detaching);
        // TODO null out other refs, including component.$$ (but need to
        // preserve final state?)
        $$.on_destroy = $$.fragment = null;
        $$.ctx = [];
    }
}
function make_dirty(component, i) {
    if (component.$$.dirty[0] === -1) {
        dirty_components.push(component);
        schedule_update();
        component.$$.dirty.fill(0);
    }
    component.$$.dirty[(i / 31) | 0] |= (1 << (i % 31));
}
function init(component, options, instance, create_fragment, not_equal, props, dirty = [-1]) {
    const parent_component = current_component;
    set_current_component(component);
    const prop_values = options.props || {};
    const $$ = component.$$ = {
        fragment: null,
        ctx: null,
        // state
        props,
        update: noop,
        not_equal,
        bound: blank_object(),
        // lifecycle
        on_mount: [],
        on_destroy: [],
        before_update: [],
        after_update: [],
        context: new Map(parent_component ? parent_component.$$.context : []),
        // everything else
        callbacks: blank_object(),
        dirty,
        skip_bound: false
    };
    let ready = false;
    $$.ctx = instance
        ? instance(component, prop_values, (i, ret, ...rest) => {
            const value = rest.length ? rest[0] : ret;
            if ($$.ctx && not_equal($$.ctx[i], $$.ctx[i] = value)) {
                if (!$$.skip_bound && $$.bound[i])
                    $$.bound[i](value);
                if (ready)
                    make_dirty(component, i);
            }
            return ret;
        })
        : [];
    $$.update();
    ready = true;
    run_all($$.before_update);
    // `false` as a special case of no DOM component
    $$.fragment = create_fragment ? create_fragment($$.ctx) : false;
    if (options.target) {
        if (options.hydrate) {
            const nodes = children(options.target);
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            $$.fragment && $$.fragment.l(nodes);
            nodes.forEach(detach);
        }
        else {
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            $$.fragment && $$.fragment.c();
        }
        if (options.intro)
            transition_in(component.$$.fragment);
        mount_component(component, options.target, options.anchor);
        flush();
    }
    set_current_component(parent_component);
}
/**
 * Base class for Svelte components. Used when dev=false.
 */
class SvelteComponent {
    $destroy() {
        destroy_component(this, 1);
        this.$destroy = noop;
    }
    $on(type, callback) {
        const callbacks = (this.$$.callbacks[type] || (this.$$.callbacks[type] = []));
        callbacks.push(callback);
        return () => {
            const index = callbacks.indexOf(callback);
            if (index !== -1)
                callbacks.splice(index, 1);
        };
    }
    $set($$props) {
        if (this.$$set && !is_empty($$props)) {
            this.$$.skip_bound = true;
            this.$$set($$props);
            this.$$.skip_bound = false;
        }
    }
}

/* src\LeftSplit.svelte generated by Svelte v3.31.0 */

function add_css() {
	var style = element("style");
	style.id = "svelte-aovzoh-style";
	style.textContent = "main.svelte-aovzoh.svelte-aovzoh{width:100%;min-width:700px;height:100%;overflow:hidden;display:flex;flex-direction:row}main.svelte-aovzoh nav.svelte-aovzoh{height:100%;overflow-y:hidden;overflow:visible;flex:0 1 auto}main.svelte-aovzoh section.svelte-aovzoh{height:100%;width:100%;overflow-x:hidden;overflow-y:auto;flex:1;box-sizing:border-box;max-height:100%}";
	append(document.head, style);
}

const get_nav_slot_changes = dirty => ({});
const get_nav_slot_context = ctx => ({});

// (43:69) nav
function fallback_block_1(ctx) {
	let t;

	return {
		c() {
			t = text("nav");
		},
		m(target, anchor) {
			insert(target, t, anchor);
		},
		d(detaching) {
			if (detaching) detach(t);
		}
	};
}

// (44:40) content
function fallback_block(ctx) {
	let t;

	return {
		c() {
			t = text("content");
		},
		m(target, anchor) {
			insert(target, t, anchor);
		},
		d(detaching) {
			if (detaching) detach(t);
		}
	};
}

function create_fragment(ctx) {
	let main;
	let nav;
	let nav_class_value;
	let t;
	let section;
	let section_class_value;
	let current;
	const nav_slot_template = /*#slots*/ ctx[5].nav;
	const nav_slot = create_slot(nav_slot_template, ctx, /*$$scope*/ ctx[4], get_nav_slot_context);
	const nav_slot_or_fallback = nav_slot || fallback_block_1();
	const default_slot_template = /*#slots*/ ctx[5].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[4], null);
	const default_slot_or_fallback = default_slot || fallback_block();

	return {
		c() {
			main = element("main");
			nav = element("nav");
			if (nav_slot_or_fallback) nav_slot_or_fallback.c();
			t = space();
			section = element("section");
			if (default_slot_or_fallback) default_slot_or_fallback.c();
			attr(nav, "class", nav_class_value = "" + (null_to_empty(/*navClasses*/ ctx[1]) + " svelte-aovzoh"));
			set_style(nav, "width", /*navWidth*/ ctx[0]);
			attr(section, "class", section_class_value = "" + (null_to_empty(/*contentClasses*/ ctx[2]) + " svelte-aovzoh"));
			attr(main, "class", "svelte-aovzoh");
		},
		m(target, anchor) {
			insert(target, main, anchor);
			append(main, nav);

			if (nav_slot_or_fallback) {
				nav_slot_or_fallback.m(nav, null);
			}

			append(main, t);
			append(main, section);

			if (default_slot_or_fallback) {
				default_slot_or_fallback.m(section, null);
			}

			current = true;
		},
		p(ctx, [dirty]) {
			if (nav_slot) {
				if (nav_slot.p && dirty & /*$$scope*/ 16) {
					update_slot(nav_slot, nav_slot_template, ctx, /*$$scope*/ ctx[4], dirty, get_nav_slot_changes, get_nav_slot_context);
				}
			}

			if (!current || dirty & /*navClasses*/ 2 && nav_class_value !== (nav_class_value = "" + (null_to_empty(/*navClasses*/ ctx[1]) + " svelte-aovzoh"))) {
				attr(nav, "class", nav_class_value);
			}

			if (!current || dirty & /*navWidth*/ 1) {
				set_style(nav, "width", /*navWidth*/ ctx[0]);
			}

			if (default_slot) {
				if (default_slot.p && dirty & /*$$scope*/ 16) {
					update_slot(default_slot, default_slot_template, ctx, /*$$scope*/ ctx[4], dirty, null, null);
				}
			}

			if (!current || dirty & /*contentClasses*/ 4 && section_class_value !== (section_class_value = "" + (null_to_empty(/*contentClasses*/ ctx[2]) + " svelte-aovzoh"))) {
				attr(section, "class", section_class_value);
			}
		},
		i(local) {
			if (current) return;
			transition_in(nav_slot_or_fallback, local);
			transition_in(default_slot_or_fallback, local);
			current = true;
		},
		o(local) {
			transition_out(nav_slot_or_fallback, local);
			transition_out(default_slot_or_fallback, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(main);
			if (nav_slot_or_fallback) nav_slot_or_fallback.d(detaching);
			if (default_slot_or_fallback) default_slot_or_fallback.d(detaching);
		}
	};
}

function instance($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;
	let { contentScrollable = true } = $$props;
	let { navWidth = "56px" } = $$props;
	let { navClasses = undefined } = $$props;
	let { contentClasses = undefined } = $$props;

	$$self.$$set = $$props => {
		if ("contentScrollable" in $$props) $$invalidate(3, contentScrollable = $$props.contentScrollable);
		if ("navWidth" in $$props) $$invalidate(0, navWidth = $$props.navWidth);
		if ("navClasses" in $$props) $$invalidate(1, navClasses = $$props.navClasses);
		if ("contentClasses" in $$props) $$invalidate(2, contentClasses = $$props.contentClasses);
		if ("$$scope" in $$props) $$invalidate(4, $$scope = $$props.$$scope);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*contentScrollable*/ 8) ;
	};

	return [navWidth, navClasses, contentClasses, contentScrollable, $$scope, slots];
}

class LeftSplit extends SvelteComponent {
	constructor(options) {
		super();
		if (!document.getElementById("svelte-aovzoh-style")) add_css();

		init(this, options, instance, create_fragment, safe_not_equal, {
			contentScrollable: 3,
			navWidth: 0,
			navClasses: 1,
			contentClasses: 2
		});
	}
}

/* src\OutlineView.svelte generated by Svelte v3.31.0 */

function add_css$1() {
	var style = element("style");
	style.id = "svelte-18ycvlm-style";
	style.textContent = "nav.svelte-18ycvlm{position:fixed;height:100%;bottom:0}";
	append(document.head, style);
}

const get_nav_slot_changes$1 = dirty => ({});
const get_nav_slot_context$1 = ctx => ({});

function create_fragment$1(ctx) {
	let nav;
	let t;
	let main;
	let current;
	const nav_slot_template = /*#slots*/ ctx[3].nav;
	const nav_slot = create_slot(nav_slot_template, ctx, /*$$scope*/ ctx[2], get_nav_slot_context$1);
	const default_slot_template = /*#slots*/ ctx[3].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[2], null);

	return {
		c() {
			nav = element("nav");
			if (nav_slot) nav_slot.c();
			t = space();
			main = element("main");
			if (default_slot) default_slot.c();
			set_style(nav, "width", /*width*/ ctx[1]);
			set_style(nav, "top", /*top*/ ctx[0]);
			attr(nav, "class", "svelte-18ycvlm");
			set_style(main, "margin-left", /*width*/ ctx[1]);
		},
		m(target, anchor) {
			insert(target, nav, anchor);

			if (nav_slot) {
				nav_slot.m(nav, null);
			}

			insert(target, t, anchor);
			insert(target, main, anchor);

			if (default_slot) {
				default_slot.m(main, null);
			}

			current = true;
		},
		p(ctx, [dirty]) {
			if (nav_slot) {
				if (nav_slot.p && dirty & /*$$scope*/ 4) {
					update_slot(nav_slot, nav_slot_template, ctx, /*$$scope*/ ctx[2], dirty, get_nav_slot_changes$1, get_nav_slot_context$1);
				}
			}

			if (!current || dirty & /*width*/ 2) {
				set_style(nav, "width", /*width*/ ctx[1]);
			}

			if (!current || dirty & /*top*/ 1) {
				set_style(nav, "top", /*top*/ ctx[0]);
			}

			if (default_slot) {
				if (default_slot.p && dirty & /*$$scope*/ 4) {
					update_slot(default_slot, default_slot_template, ctx, /*$$scope*/ ctx[2], dirty, null, null);
				}
			}

			if (!current || dirty & /*width*/ 2) {
				set_style(main, "margin-left", /*width*/ ctx[1]);
			}
		},
		i(local) {
			if (current) return;
			transition_in(nav_slot, local);
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(nav_slot, local);
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(nav);
			if (nav_slot) nav_slot.d(detaching);
			if (detaching) detach(t);
			if (detaching) detach(main);
			if (default_slot) default_slot.d(detaching);
		}
	};
}

function instance$1($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;
	let { top = "0" } = $$props;
	let { width = "200px" } = $$props;

	$$self.$$set = $$props => {
		if ("top" in $$props) $$invalidate(0, top = $$props.top);
		if ("width" in $$props) $$invalidate(1, width = $$props.width);
		if ("$$scope" in $$props) $$invalidate(2, $$scope = $$props.$$scope);
	};

	return [top, width, $$scope, slots];
}

class OutlineView extends SvelteComponent {
	constructor(options) {
		super();
		if (!document.getElementById("svelte-18ycvlm-style")) add_css$1();
		init(this, options, instance$1, create_fragment$1, safe_not_equal, { top: 0, width: 1 });
	}
}

/* src\TopSplit.svelte generated by Svelte v3.31.0 */

function add_css$2() {
	var style = element("style");
	style.id = "svelte-s60hxa-style";
	style.textContent = "main.svelte-s60hxa{width:100%;height:100%;overflow:hidden}section.svelte-s60hxa{overflow-x:hidden}header.svelte-s60hxa,footer.svelte-s60hxa{overflow:visible}";
	append(document.head, style);
}

const get_footer_slot_changes = dirty => ({});
const get_footer_slot_context = ctx => ({});
const get_header_slot_changes = dirty => ({});
const get_header_slot_context = ctx => ({});

// (29:2) {#if header}
function create_if_block_1(ctx) {
	let header_1;
	let current;
	const header_slot_template = /*#slots*/ ctx[7].header;
	const header_slot = create_slot(header_slot_template, ctx, /*$$scope*/ ctx[6], get_header_slot_context);

	return {
		c() {
			header_1 = element("header");
			if (header_slot) header_slot.c();
			set_style(header_1, "height", /*headerSize*/ ctx[0]);
			attr(header_1, "flex", "initial");
			attr(header_1, "class", "svelte-s60hxa");
		},
		m(target, anchor) {
			insert(target, header_1, anchor);

			if (header_slot) {
				header_slot.m(header_1, null);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (header_slot) {
				if (header_slot.p && dirty & /*$$scope*/ 64) {
					update_slot(header_slot, header_slot_template, ctx, /*$$scope*/ ctx[6], dirty, get_header_slot_changes, get_header_slot_context);
				}
			}

			if (!current || dirty & /*headerSize*/ 1) {
				set_style(header_1, "height", /*headerSize*/ ctx[0]);
			}
		},
		i(local) {
			if (current) return;
			transition_in(header_slot, local);
			current = true;
		},
		o(local) {
			transition_out(header_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(header_1);
			if (header_slot) header_slot.d(detaching);
		}
	};
}

// (33:2) {#if footer}
function create_if_block(ctx) {
	let footer_1;
	let current;
	const footer_slot_template = /*#slots*/ ctx[7].footer;
	const footer_slot = create_slot(footer_slot_template, ctx, /*$$scope*/ ctx[6], get_footer_slot_context);

	return {
		c() {
			footer_1 = element("footer");
			if (footer_slot) footer_slot.c();
			set_style(footer_1, "height", /*footerSize*/ ctx[1]);
			attr(footer_1, "flex", "initial");
			attr(footer_1, "class", "svelte-s60hxa");
		},
		m(target, anchor) {
			insert(target, footer_1, anchor);

			if (footer_slot) {
				footer_slot.m(footer_1, null);
			}

			current = true;
		},
		p(ctx, dirty) {
			if (footer_slot) {
				if (footer_slot.p && dirty & /*$$scope*/ 64) {
					update_slot(footer_slot, footer_slot_template, ctx, /*$$scope*/ ctx[6], dirty, get_footer_slot_changes, get_footer_slot_context);
				}
			}

			if (!current || dirty & /*footerSize*/ 2) {
				set_style(footer_1, "height", /*footerSize*/ ctx[1]);
			}
		},
		i(local) {
			if (current) return;
			transition_in(footer_slot, local);
			current = true;
		},
		o(local) {
			transition_out(footer_slot, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(footer_1);
			if (footer_slot) footer_slot.d(detaching);
		}
	};
}

function create_fragment$2(ctx) {
	let main;
	let t0;
	let section;
	let t1;
	let current;
	let if_block0 = /*header*/ ctx[2] && create_if_block_1(ctx);
	const default_slot_template = /*#slots*/ ctx[7].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[6], null);
	let if_block1 = /*footer*/ ctx[3] && create_if_block(ctx);

	return {
		c() {
			main = element("main");
			if (if_block0) if_block0.c();
			t0 = space();
			section = element("section");
			if (default_slot) default_slot.c();
			t1 = space();
			if (if_block1) if_block1.c();
			attr(section, "flex", "");
			attr(section, "style", /*contentStyle*/ ctx[4]);
			attr(section, "class", "svelte-s60hxa");
			attr(main, "layout", "column");
			attr(main, "class", "svelte-s60hxa");
		},
		m(target, anchor) {
			insert(target, main, anchor);
			if (if_block0) if_block0.m(main, null);
			append(main, t0);
			append(main, section);

			if (default_slot) {
				default_slot.m(section, null);
			}

			append(main, t1);
			if (if_block1) if_block1.m(main, null);
			current = true;
		},
		p(ctx, [dirty]) {
			if (/*header*/ ctx[2]) {
				if (if_block0) {
					if_block0.p(ctx, dirty);

					if (dirty & /*header*/ 4) {
						transition_in(if_block0, 1);
					}
				} else {
					if_block0 = create_if_block_1(ctx);
					if_block0.c();
					transition_in(if_block0, 1);
					if_block0.m(main, t0);
				}
			} else if (if_block0) {
				group_outros();

				transition_out(if_block0, 1, 1, () => {
					if_block0 = null;
				});

				check_outros();
			}

			if (default_slot) {
				if (default_slot.p && dirty & /*$$scope*/ 64) {
					update_slot(default_slot, default_slot_template, ctx, /*$$scope*/ ctx[6], dirty, null, null);
				}
			}

			if (!current || dirty & /*contentStyle*/ 16) {
				attr(section, "style", /*contentStyle*/ ctx[4]);
			}

			if (/*footer*/ ctx[3]) {
				if (if_block1) {
					if_block1.p(ctx, dirty);

					if (dirty & /*footer*/ 8) {
						transition_in(if_block1, 1);
					}
				} else {
					if_block1 = create_if_block(ctx);
					if_block1.c();
					transition_in(if_block1, 1);
					if_block1.m(main, null);
				}
			} else if (if_block1) {
				group_outros();

				transition_out(if_block1, 1, 1, () => {
					if_block1 = null;
				});

				check_outros();
			}
		},
		i(local) {
			if (current) return;
			transition_in(if_block0);
			transition_in(default_slot, local);
			transition_in(if_block1);
			current = true;
		},
		o(local) {
			transition_out(if_block0);
			transition_out(default_slot, local);
			transition_out(if_block1);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(main);
			if (if_block0) if_block0.d();
			if (default_slot) default_slot.d(detaching);
			if (if_block1) if_block1.d();
		}
	};
}

function instance$2($$self, $$props, $$invalidate) {
	let { $$slots: slots = {}, $$scope } = $$props;
	let { headerSize = "100px" } = $$props;
	let { footerSize = "100px" } = $$props;
	let { contentScrollable = true } = $$props;
	let { header = true } = $$props;
	let { footer = true } = $$props;

	$$self.$$set = $$props => {
		if ("headerSize" in $$props) $$invalidate(0, headerSize = $$props.headerSize);
		if ("footerSize" in $$props) $$invalidate(1, footerSize = $$props.footerSize);
		if ("contentScrollable" in $$props) $$invalidate(5, contentScrollable = $$props.contentScrollable);
		if ("header" in $$props) $$invalidate(2, header = $$props.header);
		if ("footer" in $$props) $$invalidate(3, footer = $$props.footer);
		if ("$$scope" in $$props) $$invalidate(6, $$scope = $$props.$$scope);
	};

	let contentStyle;

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*contentScrollable*/ 32) {
			 $$invalidate(4, contentStyle = contentScrollable
			? "overflow-y: scroll"
			: "overflow-y: hidden");
		}
	};

	return [
		headerSize,
		footerSize,
		header,
		footer,
		contentStyle,
		contentScrollable,
		$$scope,
		slots
	];
}

class TopSplit extends SvelteComponent {
	constructor(options) {
		super();
		if (!document.getElementById("svelte-s60hxa-style")) add_css$2();

		init(this, options, instance$2, create_fragment$2, safe_not_equal, {
			headerSize: 0,
			footerSize: 1,
			contentScrollable: 5,
			header: 2,
			footer: 3
		});
	}
}

export { LeftSplit as LayoutLeftSplit, OutlineView as LayoutOutlineView, TopSplit as LayoutTopSplit };
